@@ -184,73 +184,6 @@ INSERT INTO "axis" VALUES('PROJ','1','Easting','E','east','PROJ','ENh',1,'EPSG',
 INSERT INTO "axis" VALUES('PROJ','2','Northing','N','north','PROJ','ENh',2,'EPSG','9001');
 INSERT INTO "axis" VALUES('PROJ','3','Ellipsoidal height','h','up','PROJ','ENh',2,'EPSG','9001');
 
--- Consider all WGS84 related CRS are equivalent with an accuracy of 2m
-INSERT INTO "helmert_transformation" VALUES('PROJ','WGS84_TO_WGS84_G730','WGS 84 to WGS 84 (G730)','Accuracy 2m','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4326','EPSG','9053',2.0,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'',0);
-INSERT INTO "usage" VALUES(
-    'PROJ',
-    'WGS84_TO_WGS84_G730_USAGE',
-    'helmert_transformation',
-    'PROJ',
-    'WGS84_TO_WGS84_G730',
-    'EPSG','1262', -- extent
-    'EPSG','1024'  -- unknown
-);
-
-INSERT INTO "helmert_transformation" VALUES('PROJ','WGS84_TO_WGS84_G873','WGS 84 to WGS 84 (G873)','Accuracy 2m','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4326','EPSG','9054',2.0,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'',0);
-INSERT INTO "usage" VALUES(
-    'PROJ',
-    'WGS84_TO_WGS84_G873_USAGE',
-    'helmert_transformation',
-    'PROJ',
-    'WGS84_TO_WGS84_G873',
-    'EPSG','1262', -- extent
-    'EPSG','1024'  -- unknown
-);
-
-INSERT INTO "helmert_transformation" VALUES('PROJ','WGS84_TO_WGS84_G1150','WGS 84 to WGS 84 (G1150)','Accuracy 2m','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4326','EPSG','9055',2.0,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'',0);
-INSERT INTO "usage" VALUES(
-    'PROJ',
-    'WGS84_TO_WGS84_G1150_USAGE',
-    'helmert_transformation',
-    'PROJ',
-    'WGS84_TO_WGS84_G1150',
-    'EPSG','1262', -- extent
-    'EPSG','1024'  -- unknown
-);
-
-INSERT INTO "helmert_transformation" VALUES('PROJ','WGS84_TO_WGS84_G1674','WGS 84 to WGS 84 (G1674)','Accuracy 2m','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4326','EPSG','9056',2.0,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'',0);
-INSERT INTO "usage" VALUES(
-    'PROJ',
-    'WGS84_TO_WGS84_G1674_USAGE',
-    'helmert_transformation',
-    'PROJ',
-    'WGS84_TO_WGS84_G1674',
-    'EPSG','1262', -- extent
-    'EPSG','1024'  -- unknown
-);
-
-INSERT INTO "helmert_transformation" VALUES('PROJ','WGS84_TO_WGS84_G1762','WGS 84 to WGS 84 (G1762)','Accuracy 2m','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4326','EPSG','9057',2.0,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'',0);
-INSERT INTO "usage" VALUES(
-    'PROJ',
-    'WGS84_TO_WGS84_G1762_USAGE',
-    'helmert_transformation',
-    'PROJ',
-    'WGS84_TO_WGS84_G1762',
-    'EPSG','1262', -- extent
-    'EPSG','1024'  -- unknown
-);
-
-INSERT INTO "helmert_transformation" VALUES('PROJ','WGS84_TO_WGS84_TRANSIT','WGS 84 to WGS 84 (Transit)','Accuracy 2m','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4326','EPSG','8888',2.0,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'',0);
-INSERT INTO "usage" VALUES(
-    'PROJ',
-    'WGS84_TO_WGS84_TRANSIT_USAGE',
-    'helmert_transformation',
-    'PROJ',
-    'WGS84_TO_WGS84_TRANSIT',
-    'EPSG','1262', -- extent
-    'EPSG','1024'  -- unknown
-);
-
 ---- Geoid models -----
 
 INSERT INTO "geoid_model" SELECT 'GEOID99', auth_name, code FROM grid_transformation WHERE auth_name = 'EPSG' AND grid_name LIKE 'g1999%' AND deprecated = 0;
