@@ -41,6 +41,7 @@
 #include "proj_json_streaming_writer.hpp"
 
 #include <algorithm>
+#include <limits>
 #include <memory>
 #include <string>
 #include <vector>
@@ -1057,7 +1058,12 @@ const optional<std::string> &Identifier::uri() PROJ_PURE_DEFN {
 void Identifier::_exportToWKT(WKTFormatter *formatter) const {
     const bool isWKT2 = formatter->version() == WKTFormatter::Version::WKT2;
     const std::string &l_code = code();
-    const std::string &l_codeSpace = *codeSpace();
+    std::string l_codeSpace = *codeSpace();
+    std::string l_version = *version();
+    const auto &dbContext = formatter->databaseContext();
+    if (dbContext) {
+        dbContext->getAuthorityAndVersion(*codeSpace(), l_codeSpace, l_version);
+    }
     if (!l_codeSpace.empty() && !l_code.empty()) {
         if (isWKT2) {
             formatter->startNode(WKTConstants::ID, false);
@@ -1068,8 +1074,7 @@ void Identifier::_exportToWKT(WKTFormatter *formatter) const {
             } catch (const std::exception &) {
                 formatter->addQuotedString(l_code);
             }
-            if (version().has_value()) {
-                auto l_version = *(version());
+            if (!l_version.empty()) {
                 try {
                     (void)c_locale_stod(l_version);
                     formatter->add(l_version);
@@ -1078,7 +1083,7 @@ void Identifier::_exportToWKT(WKTFormatter *formatter) const {
                 }
             }
             if (authority().has_value() &&
-                *(authority()->title()) != l_codeSpace) {
+                *(authority()->title()) != *codeSpace()) {
                 formatter->startNode(WKTConstants::CITATION, false);
                 formatter->addQuotedString(*(authority()->title()));
                 formatter->endNode();
@@ -1102,7 +1107,12 @@ void Identifier::_exportToWKT(WKTFormatter *formatter) const {
 
 void Identifier::_exportToJSON(JSONFormatter *formatter) const {
     const std::string &l_code = code();
-    const std::string &l_codeSpace = *codeSpace();
+    std::string l_codeSpace = *codeSpace();
+    std::string l_version = *version();
+    const auto &dbContext = formatter->databaseContext();
+    if (dbContext) {
+        dbContext->getAuthorityAndVersion(*codeSpace(), l_codeSpace, l_version);
+    }
     if (!l_codeSpace.empty() && !l_code.empty()) {
         auto writer = formatter->writer();
         auto objContext(formatter->MakeObjectContext(nullptr, false));
@@ -1114,6 +1124,31 @@ void Identifier::_exportToJSON(JSONFormatter *formatter) const {
         } catch (const std::exception &) {
             writer->Add(l_code);
         }
+
+        if (!l_version.empty()) {
+            writer->AddObjKey("version");
+            try {
+                const double dblVersion = c_locale_stod(l_version);
+                if (dblVersion >= std::numeric_limits<int>::min() &&
+                    dblVersion <= std::numeric_limits<int>::max() &&
+                    static_cast<int>(dblVersion) == dblVersion) {
+                    writer->Add(static_cast<int>(dblVersion));
+                } else {
+                    writer->Add(dblVersion);
+                }
+            } catch (const std::exception &) {
+                writer->Add(l_version);
+            }
+        }
+        if (authority().has_value() &&
+            *(authority()->title()) != *codeSpace()) {
+            writer->AddObjKey("authority_citation");
+            writer->Add(*(authority()->title()));
+        }
+        if (uri().has_value()) {
+            writer->AddObjKey("uri");
+            writer->Add(*(uri()));
+        }
     }
 }
 
@@ -1124,7 +1159,7 @@ void Identifier::_exportToJSON(JSONFormatter *formatter) const {
 //! @cond Doxygen_Suppress
 static bool isIgnoredChar(char ch) {
     return ch == ' ' || ch == '_' || ch == '-' || ch == '/' || ch == '(' ||
-           ch == ')' || ch == '.' || ch == '&';
+           ch == ')' || ch == '.' || ch == '&' || ch == ',';
 }
 //! @endcond
 
@@ -1208,14 +1243,14 @@ bool Identifier::isEquivalentName(const char *a, const char *b) noexcept {
     size_t j = 0;
     char lastValidA = 0;
     char lastValidB = 0;
-    while (a[i] != 0 && b[j] != 0) {
+    while (a[i] != 0 || b[j] != 0) {
         char aCh = a[i];
         char bCh = b[j];
-        if (aCh == ' ' && a[i + 1] == '+' && a[i + 2] == ' ') {
+        if (aCh == ' ' && a[i + 1] == '+' && a[i + 2] == ' ' && a[i + 3] != 0) {
             i += 3;
             continue;
         }
-        if (bCh == ' ' && b[j + 1] == '+' && b[j + 2] == ' ') {
+        if (bCh == ' ' && b[j + 1] == '+' && b[j + 2] == ' ' && b[j + 3] != 0) {
             j += 3;
             continue;
         }
@@ -1253,21 +1288,18 @@ bool Identifier::isEquivalentName(const char *a, const char *b) noexcept {
                 j += strlen(replacement->utf8) - 1;
             }
         }
-        if (::tolower(aCh) != ::tolower(bCh)) {
+        if ((aCh == 0 && bCh != 0) || (aCh != 0 && bCh == 0) ||
+            ::tolower(aCh) != ::tolower(bCh)) {
             return false;
         }
         lastValidA = aCh;
         lastValidB = bCh;
-        ++i;
-        ++j;
+        if (aCh != 0)
+            ++i;
+        if (bCh != 0)
+            ++j;
     }
-    while (a[i] != 0 && isIgnoredChar(a[i])) {
-        ++i;
-    }
-    while (b[j] != 0 && isIgnoredChar(b[j])) {
-        ++j;
-    }
-    return a[i] == b[j];
+    return true;
 }
 
 // ---------------------------------------------------------------------------
